/**
 * Created by suiman on 16/1/22.
 */

/**
 * 购物栏组件
 * @name viewBuyFooter
 * @restrict E
 *
 * @description
 * 购物栏组件：
 * 活动无效，可以跳到新一期活动；
 * 活动有效，可以选择参与次数，加入购物车，跳到购物车
 *
 * @param {number} activityId 活动ID
 *
 * @example
 * <view-buy-footer activity-id=1></view-buy-footer>
 *
 */


define(
  [
    'app',
    'models/model_goods',
    'html/trolley/trolley_service',
    'components/view-buy-pop/view_buy_pop'
  ],
  function (app) {
    app.directive('viewBuyFooter', viewBuyFooter);
    viewBuyFooter.$inject = ['trolleyInfo', 'GoodsModel', 'MyUrl', 'ToastUtils', '$state']
    function viewBuyFooter(trolleyInfo, GoodsModel, MyUrl, ToastUtils, $state) {

      return {
        restrict: 'E',
        templateUrl: 'webApp/components/view-buy-footer/view_buy_footer.html',
        scope: {
          activity: "="
        },
        link: function postLink(scope, elem, attrs) {
          var unit;  //参与单位，一元区为1，十元区为10
          var goods;  //活动商品


          (function init() {
            scope.isSelectionShow = false; //控制选择框显示，默认为不显示

            scope.ready = ready;  //如果活动无效，或者网络错误，则不显示购物栏
            scope.showSelection = showSelection;  //已登录打开选择框，未登录则跳到登录界面

            scope.addToCart = addToCart;  //将商品加入购物车，参与数为参与单位（1/10）
            scope.gotoTrolley = gotoTrolley;  //跳到购物车
            scope.gotoNewActivity = gotoNewActivity;  //前往新一期活动
            scope.trolleySum = trolleySum;  //购物车商品数量

          })();

          function ready() {
            return !!(scope.activity);
          }

          function showSelection() {
            scope.buttonText = '立即夺宝';
            if (MyUrl.isLogin()) {
              scope.$broadcast('view-buy-pop.show', scope.activity);
            } else {
              $state.go('login');
            }
          }

          function addToCart() {
            scope.buttonText = '加入购物车';
            if (MyUrl.isLogin()) {
              scope.$broadcast('view-buy-pop.show', scope.activity);
            } else {
              $state.go('login');
            }
          }

          function gotoTrolley() {
            $state.go('trolley');
          }

          function gotoNewActivity() {
            var newId = scope.activity.new_activity_id;
            if(newId) {
              $state.go('activity-goodsDetail', {activityId: newId});
            }else {
              ToastUtils.showWarning('抱歉，没有新活动');
            }
          }

          function trolleySum(){
            return trolleyInfo.getGoodsInfo().length;
          }


        }
      }


    }
  });
