/**
 * 用户接口数据请求模块
 * Created by luliang on 2015/11/26.
 */
define(['app', 'utils/httpRequest', 'html/common/geturl_service'], function(app) {

    app.factory('userModel', ['httpRequest', 'MyUrl', function(httpRequest, MyUrl) {

        /**
         * 发送忘记密码短信验证
         */
        function sendForgetPasswordSms(phoneNumber,code, onSuccess, onFail) {
            var requestUrl = '?c=sms&a=send_forgot_mcode';
            var params = {
                mobile: phoneNumber,
                code:code
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }

        /**
         * 校验忘记密码的短信验证码
         */
        function checkVerificationCode(phoneNumber, verificationCode, onSuccess, onFail) {
            var requestUrl = '?c=user&a=check_forgot_mcode';
            var params = {
                mobile: phoneNumber,
                mcode: verificationCode
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }

        /**
         * 重置密码（忘记密码后重置）
         */
        function resetPassword(saveKey, newPassword, onSuccess, onFail) {
            var requestUrl = '?c=user&a=save_forgot_password';
            var params = {
                savekey: saveKey,
                password: newPassword
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }


        /**
         * 登录
         */
        function login(phonenum, password, onSuccess, onFail) {

            var requestUrl = '?c=user&a=login';
            var params = {
                name: phonenum,
                password: password
            };
            var request = httpRequest.post(requestUrl, params, onSuccess, onFail);
        }


        /**
         * 注册
         */
        function register(registerRequest, onSuccess, onFail) {

            var requestUrl = '?c=user&a=reg';
            var request = httpRequest.post(requestUrl, registerRequest, onSuccess, onFail);
        }

        /**
         * 获取注册短信验证码
         */
        function getRegisterSms(number,code, onSuccess, onFail) {
            var requestUrl = "?c=sms&a=send_reg_mcode";
            var request = httpRequest.post(requestUrl, {
                    mobile: number,
                    code:code
                },
                onSuccess, onFail
            );
        }

        function logout(onSuccess, onFail) {
            var requestUrl = '?c=user&a=logout';
            var request = httpRequest.post(requestUrl, {}, onSuccess, onFail);
        }

        /**
         * 修改密码（知道旧密码）
         */
        function modifyPassword(oldPassword, newPassword, onSuccess, onFail) {
            var requestUrl = '?c=user&a=modify_password';
            var params = {
                password: newPassword,
                password_old: oldPassword
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }


        /**
         * 获取当前登录的用户信息
         */
        function getLoginUserInfo(onSuccess, onFail) {
            var requestUrl = '?c=user&a=get_login';
            var params = {};
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }

        /**
         * 修改个人信息
         */
        function modifyUserInfo(nickname, signatures, onSuccess, onFail) {
            var requestUrl = '?c=user&a=modify_user_info';
            var params = {
                nick: nickname,
                signature: signatures
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }

        /**
         * 修改昵称
         */
        function modifyNick(nickname, onSuccess, onFail) {
            var requestUrl = '?c=user&a=modify_user_info';
            var params = {
                nick: nickname
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }

        /**
         * 修改个性签名
         */
        function modifySignature(signatures, onSuccess, onFail) {
            var requestUrl = '?c=user&a=modify_user_info';
            var params = {
                signature: signatures
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail);
        }


        /**
         * 获取我的收藏列表
         */
        function getCollectList(from, count, onSuccess, onFail, onFinal) {
            var requestUrl = '?c=fav&a=fav_list';
            var params = {
                from: from,
                count: count
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }

        /**
         * 更新用户用户头像
         * @param file
         * @param onSuccess
         * @param onFail
         * @param onFinal
         */
        function updateHeadIcon(file, onSuccess, onFail, onFinal) {
            var requestUrl = '?c=user&a=upload_icon';
            var params = {
                file: file
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }

        /**
         * 浏览器打开微信授权登录
         */
        function weChatLoginFromBrowser() {
            var requestUrl = '?c=weixin&a=go_wx';
            var params = MyUrl.getDefaultParams();
            for (var key in params) {
                requestUrl = requestUrl + '&' + key + '=' + params[key];
            }
            window.location.href = httpRequest.getBaseUrl() + requestUrl;

        }
        /**
         * 客户端微信sdk登录
         * @param token
         * @param onSuccess
         * @param onFail
         * @param onFinal
         */
        function weChatLoginFromSDK(access_token,open_id, onSuccess, onFail, onFinal) {
            var requestUrl = '?c=weixin&a=login_wx';
            var params = {
                accessToken: access_token,
                openId:open_id
            };

            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }


        /**
         * 上传图片
         * Base64编码的图片字符串，多图的话是字符串数组
         * 支持png,jpg,gif
         * 本接口支持单图和多图上传
         */
        function uploadImage(file, onSuccess, onFail, onFinal) {
            var requestUrl = '?c=bbs&a=upload_img_base64';
            var params = {
                file: file
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }

        /**
         * 绑定邀请码
         */
        function bindInviteCode(invite_code, onSuccess, onFail) {
            var requestUrl = '?c=user&a=bind_invite_code';
            var params = {
                invite_code: invite_code
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, null);
        }
        /**
         * 获取我的积分
         */
        function getMyPoint(onSuccess, onFail) {
            var requestUrl = '?c=nc_user&a=point';
            var params = {

            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, null);
        }
        /**
         * 获取我的积分明细
         */
        function getMyPointDetails(page, onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=point_detail';
            var params = {
                page: page
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 获取我的余额明细
         */
        function getAccountDetails(page, onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=money_detail';
            var params = {
                page: page
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 获取我的余额
         */
        function getAccount(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=money';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 获取签到列表
         */
        function getSignList(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=sign_already';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 签到
         */
        function sign(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=sign';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 佣金明细
         */
        function getInviteMoney(page,onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=inviteMoney';
            var params = {
              page:page
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 邀请好友明细
         */
        function getInviteUser(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=inviteUser';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 邀请好友数和佣金数
         */
        function getInviteInfo(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=inviteInfo';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 获取抽奖奖品lotteryRun
         */
        function getLottery(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=lottery';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 抽奖
         */
        function getLotteryRun(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=lotteryRun';
            var params = {

            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 抽奖奖品列表toAddPoint
         */
        function getLotteryList(page,onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=lotteryList';
            var params = {
              page:page
            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 分享通知加积分
         */
        function toAddPoint(onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=share';
            var params = {

            };
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 提现记录
         */
        function getCashRecord(page,onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=cashRecord';
            var params = {
              page:page
            };
            httpRequest.get(requestUrl, params, onSuccess, onFail, onFinal);
        }
        /**
         * 申请提现
         */
        function getApplyCash(params,onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=cash';
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }

        
        /**
         * 积分兑换余额
         */
        function changePoint(params,onSuccess, onFail, onFinal) {
            var requestUrl = '?c=nc_user&a=changePoint';
            httpRequest.post(requestUrl, params, onSuccess, onFail, onFinal);
        }
        return {
            sendForgetPasswordSms: sendForgetPasswordSms, //发送忘记短信验证码
            checkVerificationCode: checkVerificationCode, //检测验证码合法性
            resetPassword: resetPassword, //重置密码
            login: login, //登录
            logout: logout, //注销
            register: register, //注册
            getRegisterSms: getRegisterSms, //获取注册短信验证码
            modifyPassword: modifyPassword, //修改密码
            getLoginUserInfo: getLoginUserInfo, //获取登录用户信息
            modifyUserInfo: modifyUserInfo, //修改用户信息
            modifyNick: modifyNick, //修改昵称
            modifySignature: modifySignature, //修改个性签名
            getCollectList: getCollectList, //获取收藏列表
            updateHeadIcon: updateHeadIcon, //上传用户头像
            weChatLoginFromBrowser: weChatLoginFromBrowser, //浏览器打开微信授权登录
            weChatLoginFromSDK: weChatLoginFromSDK, //客户端微信sdk登录
            uploadImage: uploadImage, // 上传图片
            bindInviteCode: bindInviteCode, //绑定邀请码
            getMyPoint: getMyPoint, //获取我的积分
            getMyPointDetails: getMyPointDetails, //获取我的积分明细
            getAccountDetails: getAccountDetails, //获取我的余额明细
            getAccount: getAccount, //获取我的余额
            getSignList: getSignList, //获取签到列表
            sign: sign, //签到
            getInviteMoney:getInviteMoney,    //佣金明细
            getInviteUser:getInviteUser,    //邀请好友明细
            getInviteInfo:getInviteInfo,     //邀请好友数和佣金数
            getLottery:getLottery,        //获取抽奖奖品
            getLotteryRun:getLotteryRun,     //抽奖
            getLotteryList:getLotteryList,    //获取抽奖列表
            toAddPoint:toAddPoint,
            getCashRecord:getCashRecord, //提现申请记录
            getApplyCash:getApplyCash,  //提现申请
            changePoint: changePoint //积分兑换余额
        }

    }]);


});
